@@ -6,14 +6,14 @@ from ceader.app import Application
 
 
 def new_application(
-    files_dir: Path,
+    files: List[str],
     header_path: Path,
     file_extensions: List[str],
     skip_hidden: bool,
     debug: bool,
 ) -> Application:
     file_repo = FileDiskRepository(
-        dir_path=files_dir,
+        files=[Path(f) for f in files],
         header_path=header_path,
         skip_hidden=skip_hidden,
         extensions_to_get=file_extensions,
